@@ -1,6 +1,6 @@
 /*  
  *  Global Time - Set of clocks showing time in different parts of world.
- *  Copyright 2006 Juha Kautto (kautto.juha@kolumbus.fi)
+ *  Copyright 2006-2011 Juha Kautto (kautto.juha@kolumbus.fi)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,9 +29,9 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <libxfce4util/libxfce4util.h>
 
 #include "globaltime.h"
+#include "../src/orage-i18n.h"
 #include "timezone_selection.h"
 
 
@@ -154,8 +154,9 @@ static void add_header(GtkWidget *box, gchar *text, gboolean bold)
     gtk_widget_show(label);
 }
 
-GtkWidget *toolbar_append_button(GtkWidget *toolbar, const gchar *stock_id
-        , GtkTooltips *tooltips, const char *tooltip_text)
+static GtkWidget *toolbar_append_button(GtkWidget *toolbar
+        , const gchar *stock_id, GtkTooltips *tooltips
+        , const char *tooltip_text)
 {
     GtkWidget *button;
             
@@ -442,9 +443,9 @@ static void fill_combo_box(GtkComboBox *combo_box, char **source
     gint i;
 
     for (i = 0; strcmp(source[i], "END"); i++) {
-        gtk_combo_box_append_text(combo_box, source[i]);
+        gtk_combo_box_append_text(combo_box, _(source[i]));
         if ((strcmp(cur_value, "NO VALUE") != 0)
-        &&  ((i == 0) || (strcmp(cur_value, source[i]) == 0)))
+        &&  ((i == 0) || (strcmp(_(cur_value), _(source[i])) == 0)))
             gtk_combo_box_set_active(combo_box, i);
     }
 }
@@ -1085,7 +1086,7 @@ gboolean default_preferences(GtkWidget *widget)
 
     dec_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON (button));
     button = gtk_radio_button_new_with_label_from_widget(
-            GTK_RADIO_BUTTON(button), "None");
+            GTK_RADIO_BUTTON(button), _("None"));
     if (!clocks.decorations)
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
