@@ -10,7 +10,6 @@ extern "C" {
  CREATOR: eric 23 December 1999
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -81,7 +80,6 @@ icalcomponent* icalgauge_new_clone(icalgauge* g, icalcomponent* comp);
 **/
 
 /*
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -182,10 +180,9 @@ icalset* icalset_new_file(const char* path);
 icalset* icalset_new_file_reader(const char* path);
 icalset* icalset_new_file_writer(const char* path);
 
-/* fixed by Juha on 16.12.2010 */
 icalset* icalset_new_dir(const char* path);
-icalset* icalset_new_dir_reader(const char* path);
-icalset* icalset_new_dir_writer(const char* path);
+icalset* icalset_new_file_reader(const char* path);
+icalset* icalset_new_file_writer(const char* path);
 
 void icalset_free(icalset* set);
 
@@ -254,7 +251,6 @@ icalcomponent* icalsetiter_to_prior(icalset* set, icalsetiter* i);
  CREATOR: eric 23 December 1999
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -313,7 +309,6 @@ icalcomponent* icalcluster_get_next_component(icalcluster* cluster);
  CREATOR: eric 23 December 1999
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -443,7 +438,6 @@ extern icalfileset_options icalfileset_options_default;
  CREATOR: eric 28 November 1999
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -537,7 +531,6 @@ typedef struct icaldirset_options {
  CREATOR: eric 23 December 1999
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -602,7 +595,6 @@ icalset* icalcalendar_get_freebusy(icalcalendar* calendar);
  CREATOR: eric 21 Aug 2000
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -645,7 +637,6 @@ char* icalclassify_class_to_string(icalproperty_xlicclass c);
  CREATOR: eric 21 Aug 2000
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -720,7 +711,6 @@ icalspanlist *icalspanlist_from_vfreebusy(icalcomponent* c);
  CREATOR: eric 07 Nov 2000
 
 
- $Id$
  $Locker$
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
