@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2008 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2013 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2004-2006 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,6 @@
 typedef struct _appt_win
 {
     GtkAccelGroup *accel_group;
-    GtkTooltips *Tooltips;
 
     GtkWidget *Window;
     GtkWidget *Vbox;
@@ -47,6 +46,7 @@ typedef struct _appt_win
     GtkWidget *Duplicate;
     GtkWidget *Save;
     GtkWidget *SaveClose;
+    GtkWidget *File_insert_cb;
 
     GtkWidget *Notebook;
     GtkWidget *General_notebook_page;
